function [c, p] = SimpleController(r, e, eta, T, E)
%%
% Title: Cycle Controller
% Author: Bolun Xu
% Date: 2017-2-10
% Summary: Simple greedy controller
% Inputs:
%   delta - the maximum cycle depth
%   e - current SoC
%   r - response signal
%   eMaxPrev - current maximum SoC
%   eMinPrev - current minimum SoC
%%

% E = 1; % MWh
eUp = E*0.95; % upper SoC limit
eDn = E*0.1;  % lower SoC limit
% T = 10/3600;   % time step in hours
eta_c = eta;  % charge efficiency
eta_p = eta;  % discharge efficiency

if r>=0
  c = min( (eUp-e)/(T*eta_c), r);
  p = 0;
else
  c = 0;
  p = min( (e-eDn)*(eta_p/T), -r);
end
